class UserDownloaderConfig:
    DEFAULT_CATEGORIES = ["comments", "submitted", "saved"]
    DEFAULT_SORT = "hot"
    DEFAULT_SORT_OPTIONS = ["hot", "new", "top", "controversial"]
    DEFAULT_POST_LIMIT = None
    DEFAULT_COMMENT_LIMIT = None